==> fbp-spec-0.6.0.tgz: package/lib/subprocess.js <==
'use strict';

var common, debug;

common = require('./common');

debug = require('debug')('fbp-spec:subprocess');

exports.start = function (command, options, callback) {
  var args, child, child_process, err, prog, started, stderr, stdout;
  try {
    child_process = require('child_process');
  } catch (error) {
    err = error;
    return callback(err);
  }
  if (options.timeout == null) {
    options.timeout = 300;
  }
  started = false;
  stderr = "";
  stdout = "";
  // FIXME: using sh to interpret command will Unix-specific
  prog = 'sh';
  args = ['-c', command];
  child = child_process.spawn(prog, args);
  debug('spawned', '\'' + prog + ' ' + args.join(' ') + '\'');
  debug('waiting for output');
  child.on('error', function (err) {
    return callback(err);
  });
  child.stdout.on('data', function (data) {
    data = data.toString();
    stdout += data;
    debug('sub stdout', data);
    if (!started) {
      debug('got output, transitioning to started');
      started = true;
      // give process some time to open port
      return setTimeout(callback, 100);
    }
  });
  child.stderr.on('data', function (data) {
    data = data.toString();
    stderr += data;
    debug('sub stderr', data);
    if (!started) {
      debug('got stderr, failing');
      started = true;
      return callback(new Error('Subprocess wrote on stderr: \'' + stderr + '\''));
    }
  });
  setTimeout(function () {
    if (!started) {
      debug('timeout waiting for output, assuming started');
      started = true;
      return callback(null);
    }
  }, options.timeout);
  return child;
};

==> fbp-spec-0.6.7.tgz: package/lib/subprocess.js <==
"use strict";

var common, debug;
common = require('./common');
debug = require('debug')('fbp-spec:subprocess');

exports.start = function (command, options, callback) {
  var args, child, child_process, err, prog, started, stderr, stdout;

  try {
    child_process = require('child_process');
  } catch (error) {
    err = error;
    return callback(err);
  }

  if (options.timeout == null) {
    options.timeout = 300;
  }

  started = false;
  stderr = "";
  stdout = ""; // FIXME: using sh to interpret command will Unix-specific

  prog = 'sh';
  args = ['-c', command];
  child = child_process.spawn(prog, args);
  debug('spawned', "'".concat(prog, " ").concat(args.join(' '), "'"));
  debug('waiting for output');
  child.on('error', function (err) {
    return callback(err);
  });
  child.stdout.on('data', function (data) {
    data = data.toString();
    stdout += data;
    debug('sub stdout', data);

    if (!started) {
      debug('got output, transitioning to started');
      started = true; // give process some time to open port

      return setTimeout(callback, 100);
    }
  });
  child.stderr.on('data', function (data) {
    data = data.toString();
    stderr += data;
    debug('sub stderr', data);

    if (!started) {
      debug('got stderr, failing');
      started = true;
      return callback(new Error("Subprocess wrote on stderr: '".concat(stderr, "'")));
    }
  });
  setTimeout(function () {
    if (!started) {
      debug('timeout waiting for output, assuming started');
      started = true;
      return callback(null);
    }
  }, options.timeout);
  return child;
};
